@@ -182,10 +182,10 @@ public class GoogleAnalyticsBridge extends ReactContextBaseJavaModule{
 
         if (tracker != null) {
             tracker.send(new HitBuilders.SocialBuilder()
-                .setNetwork(network)
-                .setAction(action)
-                .setTarget(targetUrl)
-                .build());
+                    .setNetwork(network)
+                    .setAction(action)
+                    .setTarget(targetUrl)
+                    .build());
         }
     }
 
@@ -198,4 +198,24 @@ public class GoogleAnalyticsBridge extends ReactContextBaseJavaModule{
             analytics.setDryRun(enabled);
         }
     }
+
+    @ReactMethod
+    public void setDispatchInterval(Integer intervalInSeconds){
+        GoogleAnalytics analytics = getAnalyticsInstance();
+
+        if (analytics != null)
+        {
+            analytics.setLocalDispatchPeriod(intervalInSeconds);
+        }
+    }
+
+    @ReactMethod
+    public void setTrackUncaughtExceptions(Boolean enabled){
+        Tracker tracker = getTracker(_trackingId);
+
+        if (tracker != null)
+        {
+            tracker.enableExceptionReporting(enabled);
+        }
+    }
 }
